@@ -26,6 +26,9 @@ def generateTilelayer(service_url, workspace_name, task_id, geo_user='admin', ge
     }
     xurl = service_url + '/gwc/rest/seed/' + workspace_name + ':' + task_id
     res = s.post(xurl, data=payload, allow_redirects=False)
+    print '--------------- Response from generating tile layers API ---------------'
+    print res.text
+    print '--------------- End of response ---------------'
     if res.status_code == 200:
         return {
             'status': 'success'
